@@ -22,7 +22,7 @@ use constant {
 
 # =========================================================================== #
 
-our $VERSION = '1.002001';
+our $VERSION = '2.00';
 
 sub new {
     my ( $class, $in_ref )  = @_;
@@ -327,9 +327,13 @@ __END__
 
 Regexp::RegGrp - Groups a regular expressions collection
 
+=for html
+<a href='https://travis-ci.org/leejo/regexp-reggrp-perl?branch=master'><img src='https://travis-ci.org/leejo/regexp-reggrp-perl.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/leejo/regexp-reggrp-perl'><img src='https://coveralls.io/repos/leejo/regexp-reggrp-perl/badge.png?branch=master' alt='Coverage Status' /></a>
+
 =head1 VERSION
 
-Version 1.002
+Version 2.00
 
 =head1 DESCRIPTION
 
@@ -540,12 +544,12 @@ A scalar is requested by the context. The input will remain unchanged.
 
 =head1 AUTHOR
 
-Merten Falk, C<< <nevesenin at cpan.org> >>
+Merten Falk, C<< <nevesenin at cpan.org> >>. Now maintained by LEEJO
 
 =head1 BUGS
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/nevesenin/regexp-reggrp-perl/issues>.
+L<http://github.com/leejo/regexp-reggrp-perl/issues>.
 
 =head1 SUPPORT
 
@@ -560,4 +564,4 @@ Copyright 2010, 2011 Merten Falk, all rights reserved.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
